@@ -1,9 +1,13 @@
+API_KEY = "api"
+ASSERT_KEY = "assert"
 BODY_KEY = "body"
 ENDPOINTS_KEY = "endpoints"
 HEADERS_KEY = "headers"
 METHOD_KEY = "method"
 NAME_KEY = "name"
+PARAMS_KEY = "params"
 PATH_KEY = "path"
-PARAMS = "params"
 REQUESTS_KEY = "requests"
+ROOT_SCOPE = "root"
+TESTS_KEY = "tests"
 VARS_KEY = "vars"
